@@ -37,7 +37,7 @@ cCallList::~cCallList()
 
 void cCallList::Action() {
 	unsigned int retry_delay = RETRY_DELAY / 2;
-	std::string msg;
+	std::string msg, dummy;
 	cFritzTools::getFritzBoxMutex()->Lock();
 	do {
 		try {
@@ -47,9 +47,10 @@ void cCallList::Action() {
 			// now, process call list
 			cFritzTools::Login();
 			dsyslog("calllist.c: sending callList request.");
-			// force an update of the fritz!box csv list
+			// force an update of the fritz!box csv list and wait until all data is received
 			cHttpClient tc2(fritzboxConfig.url, PORT_WWW);
 			tc2 << "GET /cgi-bin/webcm?getpage=../html/de/menus/menu2.html&var:lang=de&var:pagename=foncalls&var:menu=fon HTTP/1.1\n\n\0";
+			tc2 >> dummy;
 			// retrieve csv list
 			cHttpClient tc(fritzboxConfig.url, PORT_WWW);
 			tc << "GET /cgi-bin/webcm?getpage=..%2Fhtml%2Fde%2FFRITZ%21Box_Anrufliste.csv HTTP/1.1\n\n\0";
