@@ -29,7 +29,7 @@
 #include "setup.h"
 #include "menu.h"
 
-static const char *VERSION        = "1.0.0";
+static const char *VERSION        = "1.0.1";
 static const char *DESCRIPTION    = trNOOP("Fritz!Box Plugin for AVM Fritz!Box");
 static const char *MAINMENUENTRY  = trNOOP("Fritz!Box phone book");
 
@@ -66,6 +66,9 @@ cPluginFritzbox::cPluginFritzbox(void)
 	// Initialize any member variables here.
 	// DON'T DO ANYTHING ELSE THAT MAY HAVE SIDE EFFECTS, REQUIRE GLOBAL
 	// VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!
+	fonbuch = NULL;
+	listener = NULL;
+	callList = NULL;
 }
 
 cPluginFritzbox::~cPluginFritzbox()
@@ -95,9 +98,12 @@ bool cPluginFritzbox::Start(void)
 	// Start any background activities the plugin shall perform.
 	fonbuch = cFonbuchManager::GetFonbuch();
 	callList = new cCallList();
-	listener = new cFritzListener(fritzboxConfig.url, PORT_MONITOR, fonbuch, callList);
-	if (listener)
-		listener->Start();
+	// create FritzListener only if needed
+	if (fritzboxConfig.showNumber || fritzboxConfig.pauseOnCall || fritzboxConfig.muteOnCall) {
+		listener = new cFritzListener(fritzboxConfig.url, PORT_MONITOR, fonbuch, callList);
+		if (listener)
+			listener->Start();
+	}
 	return true;
 }
 
