@@ -1,4 +1,4 @@
-	/*
+/*
  * Fritz!Box plugin for VDR
  *
  * Copyright (C) 2007 Joachim Wilke <vdr@joachim-wilke.de>
@@ -31,7 +31,6 @@ class cFritzFonbuch : public cThread, public cFonbuch {
 			friend class cFonbuchManager;
 private:
 	std::vector<cFonbuchEntry> fonbuchList;
-	bool fonbuchRead;
 	cFritzFonbuch();
 public:
 	~cFritzFonbuch();
@@ -40,7 +39,7 @@ public:
 	std::string ResolveToName(std::string &number);
 	cFonbuchEntry *RetrieveFonbuchEntry(size_t id);
 	size_t GetFonbuchSize();
-	void Reload() { this->Start(); }
+	void Reload();
 };
 
 #endif /*FRITZFONBUCH_H_*/
