@@ -33,6 +33,12 @@ private:
 	cOertlichesFonbuch();
 public:
 	virtual ~cOertlichesFonbuch();
+	/**
+	 * Take action to fill phonebook with content. 
+	 * Initialize() may be called more than once per session.
+	 * @return if initialization was successful
+	 */
+	virtual bool Initialize();
 	/**
 	 * Resolves the given number to the corresponding name.
 	 * @param number the number to resolve
