@@ -195,8 +195,11 @@ cMenuSetupFritzbox::cMenuSetupFritzbox()
 	selectedFonbookIDs   = fritzboxConfig.selectedFonbookIDs;
 	
 	size_t p = 0;
-	for(std::vector<std::string>::iterator itStr = fritzboxConfig.msn.begin(); itStr < fritzboxConfig.msn.end(); itStr++)
-		asprintf(&msn[p++], "%s", itStr->c_str());
+	for(std::vector<std::string>::iterator itStr = fritzboxConfig.msn.begin(); itStr < fritzboxConfig.msn.end(); itStr++) {
+		msn[p] = (char *) malloc(MaxFileName * sizeof(char));
+		snprintf(msn[p], MaxFileName, "%s", itStr->c_str());
+		p++;
+	}
 	// build up menu entries
 	Setup();
 }
